# Changelog

All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.1.0/),
and this project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).

## [Unreleased]

### Added

## [0.1.0] - 2025-12-30

### Added
- AST-based version modernization for Python __init__.py
- GitHub Trusted Publishing (OIDC) scaffolding
- Automated changelog management (Keep a Changelog format)
- Support for Python, Rust, and Node.js manifests
- Initial release of Prepress
- Initial project setup.
